# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class RegistryAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def query_registry(self, uuids, **kwargs):  # noqa: E501
        """Query the Registry Service to retrieve a collection of Resources records with their last read value and timestamp by their UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform Resource info that has permissions on. An administrator is able to query all of the platform Resources  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_registry(uuids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] uuids: uuids (required)
        :return: list[RegistryRecordDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_registry_with_http_info(uuids, **kwargs)  # noqa: E501
        else:
            (data) = self.query_registry_with_http_info(uuids, **kwargs)  # noqa: E501
            return data

    def query_registry_with_http_info(self, uuids, **kwargs):  # noqa: E501
        """Query the Registry Service to retrieve a collection of Resources records with their last read value and timestamp by their UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform Resource info that has permissions on. An administrator is able to query all of the platform Resources  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_registry_with_http_info(uuids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] uuids: uuids (required)
        :return: list[RegistryRecordDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_registry" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuids' is set
        if ('uuids' not in params or
                params['uuids'] is None):
            raise ValueError("Missing the required parameter `uuids` when calling `query_registry`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'uuids' in params:
            body_params = params['uuids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/registry/query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RegistryRecordDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.models.resource_query_criteria_request_within_a_timeframe_api_model import ResourceQueryCriteriaRequestWithinATimeframeAPIModel  # noqa: E501
from sparkworks_client.rest import ApiException


class TestResourceQueryCriteriaRequestWithinATimeframeAPIModel(unittest.TestCase):
    """ResourceQueryCriteriaRequestWithinATimeframeAPIModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testResourceQueryCriteriaRequestWithinATimeframeAPIModel(self):
        """Test ResourceQueryCriteriaRequestWithinATimeframeAPIModel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = sparkworks_client.models.resource_query_criteria_request_within_a_timeframe_api_model.ResourceQueryCriteriaRequestWithinATimeframeAPIModel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TheResourceSummaryDataAPIModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'average': 'dict(str, float)',
        'day': 'list[float]',
        'day_cost': 'list[float]',
        'key_name': 'str',
        'latest': 'float',
        'latest_string': 'str',
        'latest_time': 'int',
        'max': 'dict(str, int)',
        'min': 'dict(str, int)',
        'minutes5': 'list[float]',
        'minutes5cost': 'list[float]',
        'minutes60': 'list[float]',
        'minutes60cost': 'list[float]',
        'month': 'list[float]',
        'month_cost': 'list[float]'
    }

    attribute_map = {
        'average': 'average',
        'day': 'day',
        'day_cost': 'dayCost',
        'key_name': 'keyName',
        'latest': 'latest',
        'latest_string': 'latestString',
        'latest_time': 'latestTime',
        'max': 'max',
        'min': 'min',
        'minutes5': 'minutes5',
        'minutes5cost': 'minutes5cost',
        'minutes60': 'minutes60',
        'minutes60cost': 'minutes60cost',
        'month': 'month',
        'month_cost': 'monthCost'
    }

    def __init__(self, average=None, day=None, day_cost=None, key_name=None, latest=None, latest_string=None, latest_time=None, max=None, min=None, minutes5=None, minutes5cost=None, minutes60=None, minutes60cost=None, month=None, month_cost=None):  # noqa: E501
        """TheResourceSummaryDataAPIModel - a model defined in Swagger"""  # noqa: E501

        self._average = None
        self._day = None
        self._day_cost = None
        self._key_name = None
        self._latest = None
        self._latest_string = None
        self._latest_time = None
        self._max = None
        self._min = None
        self._minutes5 = None
        self._minutes5cost = None
        self._minutes60 = None
        self._minutes60cost = None
        self._month = None
        self._month_cost = None
        self.discriminator = None

        if average is not None:
            self.average = average
        if day is not None:
            self.day = day
        if day_cost is not None:
            self.day_cost = day_cost
        if key_name is not None:
            self.key_name = key_name
        if latest is not None:
            self.latest = latest
        if latest_string is not None:
            self.latest_string = latest_string
        if latest_time is not None:
            self.latest_time = latest_time
        if max is not None:
            self.max = max
        if min is not None:
            self.min = min
        if minutes5 is not None:
            self.minutes5 = minutes5
        if minutes5cost is not None:
            self.minutes5cost = minutes5cost
        if minutes60 is not None:
            self.minutes60 = minutes60
        if minutes60cost is not None:
            self.minutes60cost = minutes60cost
        if month is not None:
            self.month = month
        if month_cost is not None:
            self.month_cost = month_cost

    @property
    def average(self):
        """Gets the average of this TheResourceSummaryDataAPIModel.  # noqa: E501

        Average value of the aggregate arrays available above  # noqa: E501

        :return: The average of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: dict(str, float)
        """
        return self._average

    @average.setter
    def average(self, average):
        """Sets the average of this TheResourceSummaryDataAPIModel.

        Average value of the aggregate arrays available above  # noqa: E501

        :param average: The average of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: dict(str, float)
        """

        self._average = average

    @property
    def day(self):
        """Gets the day of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 1-day aggregates computed by the system for the Resource  # noqa: E501

        :return: The day of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._day

    @day.setter
    def day(self, day):
        """Sets the day of this TheResourceSummaryDataAPIModel.

        The 42 latest 1-day aggregates computed by the system for the Resource  # noqa: E501

        :param day: The day of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._day = day

    @property
    def day_cost(self):
        """Gets the day_cost of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 1-day electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :return: The day_cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._day_cost

    @day_cost.setter
    def day_cost(self, day_cost):
        """Sets the day_cost of this TheResourceSummaryDataAPIModel.

        The 42 latest 1-day electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :param day_cost: The day_cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._day_cost = day_cost

    @property
    def key_name(self):
        """Gets the key_name of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The Resource uniform resource identifier  # noqa: E501

        :return: The key_name of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this TheResourceSummaryDataAPIModel.

        The Resource uniform resource identifier  # noqa: E501

        :param key_name: The key_name of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: str
        """

        self._key_name = key_name

    @property
    def latest(self):
        """Gets the latest of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The last value the system received from the Resource  # noqa: E501

        :return: The latest of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._latest

    @latest.setter
    def latest(self, latest):
        """Sets the latest of this TheResourceSummaryDataAPIModel.

        The last value the system received from the Resource  # noqa: E501

        :param latest: The latest of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: float
        """

        self._latest = latest

    @property
    def latest_string(self):
        """Gets the latest_string of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The value of a string value Resource  # noqa: E501

        :return: The latest_string of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._latest_string

    @latest_string.setter
    def latest_string(self, latest_string):
        """Sets the latest_string of this TheResourceSummaryDataAPIModel.

        The value of a string value Resource  # noqa: E501

        :param latest_string: The latest_string of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: str
        """

        self._latest_string = latest_string

    @property
    def latest_time(self):
        """Gets the latest_time of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The last time the system received a new measurement from the Resource  # noqa: E501

        :return: The latest_time of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: int
        """
        return self._latest_time

    @latest_time.setter
    def latest_time(self, latest_time):
        """Sets the latest_time of this TheResourceSummaryDataAPIModel.

        The last time the system received a new measurement from the Resource  # noqa: E501

        :param latest_time: The latest_time of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: int
        """

        self._latest_time = latest_time

    @property
    def max(self):
        """Gets the max of this TheResourceSummaryDataAPIModel.  # noqa: E501

        Maximum values of the aggregate arrays available above  # noqa: E501

        :return: The max of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this TheResourceSummaryDataAPIModel.

        Maximum values of the aggregate arrays available above  # noqa: E501

        :param max: The max of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: dict(str, int)
        """

        self._max = max

    @property
    def min(self):
        """Gets the min of this TheResourceSummaryDataAPIModel.  # noqa: E501

        Minimum values of the aggregate arrays available above  # noqa: E501

        :return: The min of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this TheResourceSummaryDataAPIModel.

        Minimum values of the aggregate arrays available above  # noqa: E501

        :param min: The min of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: dict(str, int)
        """

        self._min = min

    @property
    def minutes5(self):
        """Gets the minutes5 of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 5-minute aggregates computed by the system for the Resource  # noqa: E501

        :return: The minutes5 of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._minutes5

    @minutes5.setter
    def minutes5(self, minutes5):
        """Sets the minutes5 of this TheResourceSummaryDataAPIModel.

        The 42 latest 5-minute aggregates computed by the system for the Resource  # noqa: E501

        :param minutes5: The minutes5 of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._minutes5 = minutes5

    @property
    def minutes5cost(self):
        """Gets the minutes5cost of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 5-minute electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :return: The minutes5cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._minutes5cost

    @minutes5cost.setter
    def minutes5cost(self, minutes5cost):
        """Sets the minutes5cost of this TheResourceSummaryDataAPIModel.

        The 42 latest 5-minute electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :param minutes5cost: The minutes5cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._minutes5cost = minutes5cost

    @property
    def minutes60(self):
        """Gets the minutes60 of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 1-hour aggregates computed by the system for the Resource  # noqa: E501

        :return: The minutes60 of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._minutes60

    @minutes60.setter
    def minutes60(self, minutes60):
        """Sets the minutes60 of this TheResourceSummaryDataAPIModel.

        The 42 latest 1-hour aggregates computed by the system for the Resource  # noqa: E501

        :param minutes60: The minutes60 of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._minutes60 = minutes60

    @property
    def minutes60cost(self):
        """Gets the minutes60cost of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 1-hour electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :return: The minutes60cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._minutes60cost

    @minutes60cost.setter
    def minutes60cost(self, minutes60cost):
        """Sets the minutes60cost of this TheResourceSummaryDataAPIModel.

        The 42 latest 1-hour electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :param minutes60cost: The minutes60cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._minutes60cost = minutes60cost

    @property
    def month(self):
        """Gets the month of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 1-month aggregates computed by the system for the Resource  # noqa: E501

        :return: The month of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._month

    @month.setter
    def month(self, month):
        """Sets the month of this TheResourceSummaryDataAPIModel.

        The 42 latest 1-month aggregates computed by the system for the Resource  # noqa: E501

        :param month: The month of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._month = month

    @property
    def month_cost(self):
        """Gets the month_cost of this TheResourceSummaryDataAPIModel.  # noqa: E501

        The 42 latest 1-month electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :return: The month_cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :rtype: list[float]
        """
        return self._month_cost

    @month_cost.setter
    def month_cost(self, month_cost):
        """Sets the month_cost of this TheResourceSummaryDataAPIModel.

        The 42 latest 1-month electricity cost values computed by the system for the Resource if enabled  # noqa: E501

        :param month_cost: The month_cost of this TheResourceSummaryDataAPIModel.  # noqa: E501
        :type: list[float]
        """

        self._month_cost = month_cost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TheResourceSummaryDataAPIModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TheResourceSummaryDataAPIModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.unit_api_api import UnitAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestUnitAPIApi(unittest.TestCase):
    """UnitAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.unit_api_api.UnitAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_unit(self):
        """Test case for create_unit

        Create a Unit  # noqa: E501
        """
        pass

    def test_create_unit_conversion(self):
        """Test case for create_unit_conversion

        Create a Unit Conversion  # noqa: E501
        """
        pass

    def test_delete_unit(self):
        """Test case for delete_unit

        Delete a Unit by its UUID  # noqa: E501
        """
        pass

    def test_delete_unit_conversion(self):
        """Test case for delete_unit_conversion

        Delete a Unit Conversion by its UUID  # noqa: E501
        """
        pass

    def test_get_unit_by_u_uid(self):
        """Test case for get_unit_by_u_uid

        Retrieve a Unit by its UUID  # noqa: E501
        """
        pass

    def test_get_unit_conversion_by_u_uid(self):
        """Test case for get_unit_conversion_by_u_uid

        Retrieve a Unit Conversion by its UUID  # noqa: E501
        """
        pass

    def test_list_all_unit_conversions(self):
        """Test case for list_all_unit_conversions

        Retrieve a collection of Unit Conversions  # noqa: E501
        """
        pass

    def test_list_all_units(self):
        """Test case for list_all_units

        Retrieve a collection of Units  # noqa: E501
        """
        pass

    def test_query_unit_conversions(self):
        """Test case for query_unit_conversions

        Retrieve a List of Unit Conversions by a query  # noqa: E501
        """
        pass

    def test_query_units(self):
        """Test case for query_units

        Retrieve a Unit by a query  # noqa: E501
        """
        pass

    def test_update_unit(self):
        """Test case for update_unit

        Update Unit  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class GatewayAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def count_gateways(self, **kwargs):  # noqa: E501
        """Count Gateways  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the number of Gateways that has permissions on. An administrator is able to retrieve the number of all Gateways.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_gateways(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.count_gateways_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.count_gateways_with_http_info(**kwargs)  # noqa: E501
            return data

    def count_gateways_with_http_info(self, **kwargs):  # noqa: E501
        """Count Gateways  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the number of Gateways that has permissions on. An administrator is able to retrieve the number of all Gateways.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_gateways_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count_gateways" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_gateway(self, gateway_create_dto, **kwargs):  # noqa: E501
        """Create a new Gateway  # noqa: E501

        A Spark Works authenticated user is able to request a new Gateway creation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_gateway(gateway_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GatewayCreateDTO gateway_create_dto: Gateway Creation API Model (required)
        :return: GatewayDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_gateway_with_http_info(gateway_create_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.create_gateway_with_http_info(gateway_create_dto, **kwargs)  # noqa: E501
            return data

    def create_gateway_with_http_info(self, gateway_create_dto, **kwargs):  # noqa: E501
        """Create a new Gateway  # noqa: E501

        A Spark Works authenticated user is able to request a new Gateway creation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_gateway_with_http_info(gateway_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GatewayCreateDTO gateway_create_dto: Gateway Creation API Model (required)
        :return: GatewayDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['gateway_create_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'gateway_create_dto' is set
        if ('gateway_create_dto' not in params or
                params['gateway_create_dto'] is None):
            raise ValueError("Missing the required parameter `gateway_create_dto` when calling `create_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'gateway_create_dto' in params:
            body_params = params['gateway_create_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GatewayDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_gateway(self, uuid, **kwargs):  # noqa: E501
        """Delete Gateway by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to remove a Spark Works Gateway that has permissions on by its unique identifier. An administrator is able to remove any Gateway of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_gateway(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Gateway UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_gateway_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_gateway_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def delete_gateway_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Delete Gateway by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to remove a Spark Works Gateway that has permissions on by its unique identifier. An administrator is able to remove any Gateway of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_gateway_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Gateway UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `delete_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway/{uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_gateway_resources(self, uuid, **kwargs):  # noqa: E501
        """Get the Resources of a Gateway by the Gateway UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Resources of Gateway that has permissions on by its UUID. An administrator is able to retrieve the Resources of any Gateway.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_gateway_resources(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Gateway UUID (required)
        :return: list[ResourceDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_gateway_resources_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_gateway_resources_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_gateway_resources_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Get the Resources of a Gateway by the Gateway UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Resources of Gateway that has permissions on by its UUID. An administrator is able to retrieve the Resources of any Gateway.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_gateway_resources_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Gateway UUID (required)
        :return: list[ResourceDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_gateway_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_gateway_resources`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway/{uuid}/resource', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ResourceDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_gateways(self, gateway_query, **kwargs):  # noqa: E501
        """Retrieve a Gateway by a query  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Gateway that has permissions on by a query object. An administrator is able to get any Gateway by a query object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_gateways(gateway_query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GatewayQueryDTO gateway_query: The Gateway Query (required)
        :return: GatewayDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_gateways_with_http_info(gateway_query, **kwargs)  # noqa: E501
        else:
            (data) = self.query_gateways_with_http_info(gateway_query, **kwargs)  # noqa: E501
            return data

    def query_gateways_with_http_info(self, gateway_query, **kwargs):  # noqa: E501
        """Retrieve a Gateway by a query  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Gateway that has permissions on by a query object. An administrator is able to get any Gateway by a query object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_gateways_with_http_info(gateway_query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GatewayQueryDTO gateway_query: The Gateway Query (required)
        :return: GatewayDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['gateway_query']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_gateways" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'gateway_query' is set
        if ('gateway_query' not in params or
                params['gateway_query'] is None):
            raise ValueError("Missing the required parameter `gateway_query` when calling `query_gateways`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'gateway_query' in params:
            body_params = params['gateway_query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway/query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GatewayDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_gateway_by_uuid(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Gateway by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Gateway that has permissions on by its UUID. An administrator is able to get any Gateway by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_gateway_by_uuid(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Gateway UUID (required)
        :return: GatewayDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_gateway_by_uuid_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_gateway_by_uuid_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def retrieve_gateway_by_uuid_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Gateway by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Gateway that has permissions on by its UUID. An administrator is able to get any Gateway by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_gateway_by_uuid_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Gateway UUID (required)
        :return: GatewayDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_gateways" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `retrieve_gateways`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway/{uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GatewayDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_gateways(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Gateways  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform Gateways that has permissions on. An administrator is able to query all of the platform Gateways  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_gateways(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[GatewayDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_gateways_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_gateways_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_gateways_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Gateways  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform Gateways that has permissions on. An administrator is able to query all of the platform Gateways  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_gateways_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[GatewayDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_gateways1" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/gateway', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GatewayDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class GroupAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def count_groups(self, **kwargs):  # noqa: E501
        """Count Groups  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the number of Groups that has permissions on. An administrator is able to retrieve the number of all Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.count_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.count_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def count_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Count Groups  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the number of Groups that has permissions on. An administrator is able to retrieve the number of all Groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_group(self, group_create_dto, **kwargs):  # noqa: E501
        """Create a new Group  # noqa: E501

        A Spark Works authenticated user is able to request a new Group creation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_group(group_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GroupCreateDTO group_create_dto: Group Creation API Model (required)
        :return: GroupDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_group_with_http_info(group_create_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.create_group_with_http_info(group_create_dto, **kwargs)  # noqa: E501
            return data

    def create_group_with_http_info(self, group_create_dto, **kwargs):  # noqa: E501
        """Create a new Group  # noqa: E501

        A Spark Works authenticated user is able to request a new Group creation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_group_with_http_info(group_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GroupCreateDTO group_create_dto: Group Creation API Model (required)
        :return: GroupDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_create_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_create_dto' is set
        if ('group_create_dto' not in params or
                params['group_create_dto'] is None):
            raise ValueError("Missing the required parameter `group_create_dto` when calling `create_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group_create_dto' in params:
            body_params = params['group_create_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_group_branch(self, uuid, **kwargs):  # noqa: E501
        """Delete Group branch by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to remove a Spark Works Group branch that has permissions on by its UUID. An administrator is able to remove any Group branch of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_branch(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_group_branch_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_group_branch_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def delete_group_branch_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Delete Group branch by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to remove a Spark Works Group branch that has permissions on by its UUID. An administrator is able to remove any Group branch of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_branch_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group_branch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `delete_group_branch`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/{uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_gateways(self, uuid, **kwargs):  # noqa: E501
        """Get the Gateways of a Group by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Gateways of Group that has permissions on by its UUID. An administrator is able to retrieve the Gateways of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_gateways(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: list[GatewayDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_gateways_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_gateways_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_group_gateways_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Get the Gateways of a Group by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Gateways of Group that has permissions on by its UUID. An administrator is able to retrieve the Gateways of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_gateways_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: list[GatewayDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_gateways" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_group_gateways`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/{uuid}/gateway', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GatewayDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_resources(self, uuid, **kwargs):  # noqa: E501
        """Get the Resources of a Group by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Resources of Group that has permissions on by its UUID. An administrator is able to retrieve the Resources of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_resources(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: list[ResourceDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_resources_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_resources_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_group_resources_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Get the Resources of a Group by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Resources of Group that has permissions on by its UUID. An administrator is able to retrieve the Resources of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_resources_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: list[ResourceDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_group_resources`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/{uuid}/resource', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ResourceDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_main_level_groups(self, **kwargs):  # noqa: E501
        """List the main level Groups  # noqa: E501

        A Spark Works Accounts authenticated common user is able to list the Groups of main level that has permissions on. An administrator is able to list all the Groups of main level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_main_level_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[GroupDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_main_level_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_main_level_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_main_level_groups_with_http_info(self, **kwargs):  # noqa: E501
        """List the main level Groups  # noqa: E501

        A Spark Works Accounts authenticated common user is able to list the Groups of main level that has permissions on. An administrator is able to list all the Groups of main level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_main_level_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[GroupDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_main_level_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/main', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GroupDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sub_groups(self, uuid, depth, **kwargs):  # noqa: E501
        """Get the Subgroups of a Group by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Subgroups of Group that has permissions on by its UUID. An administrator is able to retrieve the Subgroups of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sub_groups(uuid, depth, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :param int depth: depth (required)
        :return: list[GroupDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sub_groups_with_http_info(uuid, depth, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sub_groups_with_http_info(uuid, depth, **kwargs)  # noqa: E501
            return data

    def get_sub_groups_with_http_info(self, uuid, depth, **kwargs):  # noqa: E501
        """Get the Subgroups of a Group by the Group UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the Subgroups of Group that has permissions on by its UUID. An administrator is able to retrieve the Subgroups of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sub_groups_with_http_info(uuid, depth, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :param int depth: depth (required)
        :return: list[GroupDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'depth']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sub_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_sub_groups`")  # noqa: E501
        # verify the required parameter 'depth' is set
        if ('depth' not in params or
                params['depth'] is None):
            raise ValueError("Missing the required parameter `depth` when calling `get_sub_groups`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501
        if 'depth' in params:
            path_params['depth'] = params['depth']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/{uuid}/subgroup/{depth}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GroupDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def move_group_branch(self, source_uuid, target_uuid, **kwargs):  # noqa: E501
        """Move Group Branch  # noqa: E501

        A Spark Works Accounts authenticated common user is able to move a Spark Works Group branch that has permissions on under another Group that has permissions on. An administrator is able to move any Group of the platform under any other Group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_group_branch(source_uuid, target_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_uuid: The source Group UUID (required)
        :param str target_uuid: The target Group UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.move_group_branch_with_http_info(source_uuid, target_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.move_group_branch_with_http_info(source_uuid, target_uuid, **kwargs)  # noqa: E501
            return data

    def move_group_branch_with_http_info(self, source_uuid, target_uuid, **kwargs):  # noqa: E501
        """Move Group Branch  # noqa: E501

        A Spark Works Accounts authenticated common user is able to move a Spark Works Group branch that has permissions on under another Group that has permissions on. An administrator is able to move any Group of the platform under any other Group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_group_branch_with_http_info(source_uuid, target_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_uuid: The source Group UUID (required)
        :param str target_uuid: The target Group UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['source_uuid', 'target_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method move_group_branch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'source_uuid' is set
        if ('source_uuid' not in params or
                params['source_uuid'] is None):
            raise ValueError("Missing the required parameter `source_uuid` when calling `move_group_branch`")  # noqa: E501
        # verify the required parameter 'target_uuid' is set
        if ('target_uuid' not in params or
                params['target_uuid'] is None):
            raise ValueError("Missing the required parameter `target_uuid` when calling `move_group_branch`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'source_uuid' in params:
            path_params['sourceUUID'] = params['source_uuid']  # noqa: E501
        if 'target_uuid' in params:
            path_params['targetUUID'] = params['target_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/move/{sourceUUID}/{targetUUID}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_group(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Group by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Group that has permissions on by its UUID. An administrator is able to get any Group by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_group(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: GroupDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_group_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_group_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def retrieve_group_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Group by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Group that has permissions on by its UUID. An administrator is able to get any Group by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_group_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :return: GroupDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `retrieve_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/{uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_groups(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Groups  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform Groups that has permissions on. An administrator is able to query all of the platform Groups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[GroupDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Groups  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform Groups that has permissions on. An administrator is able to query all of the platform Groups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[GroupDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GroupDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_group(self, uuid, group_update_dto, **kwargs):  # noqa: E501
        """Update Group  # noqa: E501

        A Spark Works Accounts authenticated common user is able to update a Group's values that has permission on. An administrator is able to update the values of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_group(uuid, group_update_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :param GroupUpdateDTO group_update_dto: groupUpdateDTO (required)
        :return: GroupDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_group_with_http_info(uuid, group_update_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.update_group_with_http_info(uuid, group_update_dto, **kwargs)  # noqa: E501
            return data

    def update_group_with_http_info(self, uuid, group_update_dto, **kwargs):  # noqa: E501
        """Update Group  # noqa: E501

        A Spark Works Accounts authenticated common user is able to update a Group's values that has permission on. An administrator is able to update the values of any Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_group_with_http_info(uuid, group_update_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :param GroupUpdateDTO group_update_dto: groupUpdateDTO (required)
        :return: GroupDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'group_update_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `update_group`")  # noqa: E501
        # verify the required parameter 'group_update_dto' is set
        if ('group_update_dto' not in params or
                params['group_update_dto'] is None):
            raise ValueError("Missing the required parameter `group_update_dto` when calling `update_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group_update_dto' in params:
            body_params = params['group_update_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/group/{uuid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.gateway_api_api import GatewayAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestGatewayAPIApi(unittest.TestCase):
    """GatewayAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.gateway_api_api.GatewayAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_gateways(self):
        """Test case for count_gateways

        Count Gateways  # noqa: E501
        """
        pass

    def test_create_gateway(self):
        """Test case for create_gateway

        Create a new Gateway  # noqa: E501
        """
        pass

    def test_delete_gateway(self):
        """Test case for delete_gateway

        Delete Gateway by its UUID  # noqa: E501
        """
        pass

    def test_get_gateway_resources(self):
        """Test case for get_gateway_resources

        Get the Resources of a Gateway by the Gateway UUID  # noqa: E501
        """
        pass

    def test_query_gateways(self):
        """Test case for query_gateways

        Retrieve a Gateway by a query  # noqa: E501
        """
        pass

    def test_retrieve_gateways(self):
        """Test case for retrieve_gateways

        Retrieve a Gateway by its UUID  # noqa: E501
        """
        pass

    def test_retrieve_gateways1(self):
        """Test case for retrieve_gateways1

        Retrieve a collection of Gateways  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.group_api_api import GroupAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestGroupAPIApi(unittest.TestCase):
    """GroupAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.group_api_api.GroupAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_groups(self):
        """Test case for count_groups

        Count Groups  # noqa: E501
        """
        pass

    def test_create_group(self):
        """Test case for create_group

        Create a new Group  # noqa: E501
        """
        pass

    def test_delete_group_branch(self):
        """Test case for delete_group_branch

        Delete Group branch by the Group UUID  # noqa: E501
        """
        pass

    def test_get_group_gateways(self):
        """Test case for get_group_gateways

        Get the Gateways of a Group by the Group UUID  # noqa: E501
        """
        pass

    def test_get_group_resources(self):
        """Test case for get_group_resources

        Get the Resources of a Group by the Group UUID  # noqa: E501
        """
        pass

    def test_get_main_level_groups(self):
        """Test case for get_main_level_groups

        List the main level Groups  # noqa: E501
        """
        pass

    def test_get_sub_groups(self):
        """Test case for get_sub_groups

        Get the Subgroups of a Group by the Group UUID  # noqa: E501
        """
        pass

    def test_move_group_branch(self):
        """Test case for move_group_branch

        Move Group Branch  # noqa: E501
        """
        pass

    def test_retrieve_group(self):
        """Test case for retrieve_group

        Retrieve a Group by its UUID  # noqa: E501
        """
        pass

    def test_retrieve_groups(self):
        """Test case for retrieve_groups

        Retrieve a collection of Groups  # noqa: E501
        """
        pass

    def test_update_group(self):
        """Test case for update_group

        Update Group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.registry_api_api import RegistryAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestRegistryAPIApi(unittest.TestCase):
    """RegistryAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.registry_api_api.RegistryAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_query_registry(self):
        """Test case for query_registry

        Query the Registry Service to retrieve a collection of Resources records with their last read value and timestamp by their UUID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceLatestValuesResponseAPIModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'latest': 'float',
        'latest_day': 'float',
        'latest_min5': 'float',
        'latest_min60': 'float',
        'latest_month': 'float',
        'latest_time': 'int',
        'uom': 'str',
        'uri': 'str',
        'uuid': 'str'
    }

    attribute_map = {
        'latest': 'latest',
        'latest_day': 'latestDay',
        'latest_min5': 'latestMin5',
        'latest_min60': 'latestMin60',
        'latest_month': 'latestMonth',
        'latest_time': 'latestTime',
        'uom': 'uom',
        'uri': 'uri',
        'uuid': 'uuid'
    }

    def __init__(self, latest=None, latest_day=None, latest_min5=None, latest_min60=None, latest_month=None, latest_time=None, uom=None, uri=None, uuid=None):  # noqa: E501
        """ResourceLatestValuesResponseAPIModel - a model defined in Swagger"""  # noqa: E501

        self._latest = None
        self._latest_day = None
        self._latest_min5 = None
        self._latest_min60 = None
        self._latest_month = None
        self._latest_time = None
        self._uom = None
        self._uri = None
        self._uuid = None
        self.discriminator = None

        if latest is not None:
            self.latest = latest
        if latest_day is not None:
            self.latest_day = latest_day
        if latest_min5 is not None:
            self.latest_min5 = latest_min5
        if latest_min60 is not None:
            self.latest_min60 = latest_min60
        if latest_month is not None:
            self.latest_month = latest_month
        if latest_time is not None:
            self.latest_time = latest_time
        if uom is not None:
            self.uom = uom
        if uri is not None:
            self.uri = uri
        if uuid is not None:
            self.uuid = uuid

    @property
    def latest(self):
        """Gets the latest of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The last value the system received from the Resource  # noqa: E501

        :return: The latest of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._latest

    @latest.setter
    def latest(self, latest):
        """Sets the latest of this ResourceLatestValuesResponseAPIModel.

        The last value the system received from the Resource  # noqa: E501

        :param latest: The latest of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: float
        """

        self._latest = latest

    @property
    def latest_day(self):
        """Gets the latest_day of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The last 1 day aggregate computed by the system for the Resource  # noqa: E501

        :return: The latest_day of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._latest_day

    @latest_day.setter
    def latest_day(self, latest_day):
        """Sets the latest_day of this ResourceLatestValuesResponseAPIModel.

        The last 1 day aggregate computed by the system for the Resource  # noqa: E501

        :param latest_day: The latest_day of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: float
        """

        self._latest_day = latest_day

    @property
    def latest_min5(self):
        """Gets the latest_min5 of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The last 5 minute aggregate computed by the system for the Resource  # noqa: E501

        :return: The latest_min5 of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._latest_min5

    @latest_min5.setter
    def latest_min5(self, latest_min5):
        """Sets the latest_min5 of this ResourceLatestValuesResponseAPIModel.

        The last 5 minute aggregate computed by the system for the Resource  # noqa: E501

        :param latest_min5: The latest_min5 of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: float
        """

        self._latest_min5 = latest_min5

    @property
    def latest_min60(self):
        """Gets the latest_min60 of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The last 1 hour aggregate computed by the system for the Resource  # noqa: E501

        :return: The latest_min60 of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._latest_min60

    @latest_min60.setter
    def latest_min60(self, latest_min60):
        """Sets the latest_min60 of this ResourceLatestValuesResponseAPIModel.

        The last 1 hour aggregate computed by the system for the Resource  # noqa: E501

        :param latest_min60: The latest_min60 of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: float
        """

        self._latest_min60 = latest_min60

    @property
    def latest_month(self):
        """Gets the latest_month of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The last monthly aggregate computed by the system for the Resource  # noqa: E501

        :return: The latest_month of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._latest_month

    @latest_month.setter
    def latest_month(self, latest_month):
        """Sets the latest_month of this ResourceLatestValuesResponseAPIModel.

        The last monthly aggregate computed by the system for the Resource  # noqa: E501

        :param latest_month: The latest_month of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: float
        """

        self._latest_month = latest_month

    @property
    def latest_time(self):
        """Gets the latest_time of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The last time the system received a new measurement from the Resource  # noqa: E501

        :return: The latest_time of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: int
        """
        return self._latest_time

    @latest_time.setter
    def latest_time(self, latest_time):
        """Sets the latest_time of this ResourceLatestValuesResponseAPIModel.

        The last time the system received a new measurement from the Resource  # noqa: E501

        :param latest_time: The latest_time of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: int
        """

        self._latest_time = latest_time

    @property
    def uom(self):
        """Gets the uom of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The unit of measurement of a 'Sensor' Resource  # noqa: E501

        :return: The uom of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._uom

    @uom.setter
    def uom(self, uom):
        """Sets the uom of this ResourceLatestValuesResponseAPIModel.

        The unit of measurement of a 'Sensor' Resource  # noqa: E501

        :param uom: The uom of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: str
        """

        self._uom = uom

    @property
    def uri(self):
        """Gets the uri of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The Resource uniform resource identifier  # noqa: E501

        :return: The uri of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ResourceLatestValuesResponseAPIModel.

        The Resource uniform resource identifier  # noqa: E501

        :param uri: The uri of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def uuid(self):
        """Gets the uuid of this ResourceLatestValuesResponseAPIModel.  # noqa: E501

        The internal Resource unique Identifier  # noqa: E501

        :return: The uuid of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this ResourceLatestValuesResponseAPIModel.

        The internal Resource unique Identifier  # noqa: E501

        :param uuid: The uuid of this ResourceLatestValuesResponseAPIModel.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceLatestValuesResponseAPIModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceLatestValuesResponseAPIModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UnitConversionDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'method': 'str',
        'source_uuid': 'str',
        'target_uuid': 'str',
        'uuid': 'str'
    }

    attribute_map = {
        'method': 'method',
        'source_uuid': 'sourceUuid',
        'target_uuid': 'targetUuid',
        'uuid': 'uuid'
    }

    def __init__(self, method=None, source_uuid=None, target_uuid=None, uuid=None):  # noqa: E501
        """UnitConversionDTO - a model defined in Swagger"""  # noqa: E501

        self._method = None
        self._source_uuid = None
        self._target_uuid = None
        self._uuid = None
        self.discriminator = None

        if method is not None:
            self.method = method
        if source_uuid is not None:
            self.source_uuid = source_uuid
        if target_uuid is not None:
            self.target_uuid = target_uuid
        if uuid is not None:
            self.uuid = uuid

    @property
    def method(self):
        """Gets the method of this UnitConversionDTO.  # noqa: E501


        :return: The method of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this UnitConversionDTO.


        :param method: The method of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def source_uuid(self):
        """Gets the source_uuid of this UnitConversionDTO.  # noqa: E501


        :return: The source_uuid of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._source_uuid

    @source_uuid.setter
    def source_uuid(self, source_uuid):
        """Sets the source_uuid of this UnitConversionDTO.


        :param source_uuid: The source_uuid of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._source_uuid = source_uuid

    @property
    def target_uuid(self):
        """Gets the target_uuid of this UnitConversionDTO.  # noqa: E501


        :return: The target_uuid of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._target_uuid

    @target_uuid.setter
    def target_uuid(self, target_uuid):
        """Sets the target_uuid of this UnitConversionDTO.


        :param target_uuid: The target_uuid of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._target_uuid = target_uuid

    @property
    def uuid(self):
        """Gets the uuid of this UnitConversionDTO.  # noqa: E501


        :return: The uuid of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this UnitConversionDTO.


        :param uuid: The uuid of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UnitConversionDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UnitConversionDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class PhenomenonAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_phenomenon(self, phenomenon_create_dto, **kwargs):  # noqa: E501
        """Create a Phenomenon  # noqa: E501

        A Spark Works Accounts authenticated user is able to create a Phenomenon.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_phenomenon(phenomenon_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PhenomenonCreateDTO phenomenon_create_dto: The Phenomenon Query (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_phenomenon_with_http_info(phenomenon_create_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.create_phenomenon_with_http_info(phenomenon_create_dto, **kwargs)  # noqa: E501
            return data

    def create_phenomenon_with_http_info(self, phenomenon_create_dto, **kwargs):  # noqa: E501
        """Create a Phenomenon  # noqa: E501

        A Spark Works Accounts authenticated user is able to create a Phenomenon.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_phenomenon_with_http_info(phenomenon_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PhenomenonCreateDTO phenomenon_create_dto: The Phenomenon Query (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['phenomenon_create_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_phenomenon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'phenomenon_create_dto' is set
        if ('phenomenon_create_dto' not in params or
                params['phenomenon_create_dto'] is None):
            raise ValueError("Missing the required parameter `phenomenon_create_dto` when calling `create_phenomenon`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'phenomenon_create_dto' in params:
            body_params = params['phenomenon_create_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/phenomenon', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PhenomenonDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_phenomenon(self, uuid, **kwargs):  # noqa: E501
        """Delete a Phenomenon by its UUID  # noqa: E501

        A Spark Works Accounts authenticated user is able to delete a Phenomenon by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_phenomenon(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Phenomenon UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_phenomenon_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_phenomenon_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def delete_phenomenon_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Delete a Phenomenon by its UUID  # noqa: E501

        A Spark Works Accounts authenticated user is able to delete a Phenomenon by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_phenomenon_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Phenomenon UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_phenomenon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `delete_phenomenon`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/phenomenon/{uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_phenomenon_by_u_uid(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Phenomenon by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Phenomenon that has permissions on by its UUID. An administrator is able to get any Phenomenon by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_phenomenon_by_u_uid(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Phenomenon UUID (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_phenomenon_by_u_uid_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_phenomenon_by_u_uid_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_phenomenon_by_u_uid_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Phenomenon by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Phenomenon that has permissions on by its UUID. An administrator is able to get any Phenomenon by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_phenomenon_by_u_uid_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Phenomenon UUID (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_phenomenon_by_u_uid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_phenomenon_by_u_uid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/phenomenon/{uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PhenomenonDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_all_phenomena(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Phenomenons  # noqa: E501

        A Spark Works Accounts authenticated user is able to retrieve all of the Platform Phenomenons.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_all_phenomena(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PhenomenonDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_all_phenomena_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_all_phenomena_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_all_phenomena_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Phenomenons  # noqa: E501

        A Spark Works Accounts authenticated user is able to retrieve all of the Platform Phenomenons.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_all_phenomena_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PhenomenonDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_all_phenomenons" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/phenomenon', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PhenomenonDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_phenomena(self, phenomenon_query_dto, **kwargs):  # noqa: E501
        """Retrieve a Phenomenon by a query  # noqa: E501

        A Spark Works Accounts authenticated user is able to retrieve a Phenomenon.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_phenomena(phenomenon_query_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PhenomenonQueryDTO phenomenon_query_dto: The Phenomenon Query (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_phenomena_with_http_info(phenomenon_query_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_phenomena_with_http_info(phenomenon_query_dto, **kwargs)  # noqa: E501
            return data

    def query_phenomena_with_http_info(self, phenomenon_query_dto, **kwargs):  # noqa: E501
        """Retrieve a Phenomenon by a query  # noqa: E501

        A Spark Works Accounts authenticated user is able to retrieve a Phenomenon.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_phenomena_with_http_info(phenomenon_query_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PhenomenonQueryDTO phenomenon_query_dto: The Phenomenon Query (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['phenomenon_query_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_phenomenons" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'phenomenon_query_dto' is set
        if ('phenomenon_query_dto' not in params or
                params['phenomenon_query_dto'] is None):
            raise ValueError("Missing the required parameter `phenomenon_query_dto` when calling `query_phenomenons`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'phenomenon_query_dto' in params:
            body_params = params['phenomenon_query_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/phenomenon/query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PhenomenonDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_phenomenon(self, uuid, update_dto, **kwargs):  # noqa: E501
        """Update Phenomenon  # noqa: E501

        A Spark Works Accounts administrator is able to update a Phenomenon by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_phenomenon(uuid, update_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Phenomenon UUID (required)
        :param PhenomenonUpdateDTO update_dto: updateDTO (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_phenomenon_with_http_info(uuid, update_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.update_phenomenon_with_http_info(uuid, update_dto, **kwargs)  # noqa: E501
            return data

    def update_phenomenon_with_http_info(self, uuid, update_dto, **kwargs):  # noqa: E501
        """Update Phenomenon  # noqa: E501

        A Spark Works Accounts administrator is able to update a Phenomenon by its UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_phenomenon_with_http_info(uuid, update_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Phenomenon UUID (required)
        :param PhenomenonUpdateDTO update_dto: updateDTO (required)
        :return: PhenomenonDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'update_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_phenomenon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `update_phenomenon`")  # noqa: E501
        # verify the required parameter 'update_dto' is set
        if ('update_dto' not in params or
                params['update_dto'] is None):
            raise ValueError("Missing the required parameter `update_dto` when calling `update_phenomenon`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_dto' in params:
            body_params = params['update_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/phenomenon/{uuid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PhenomenonDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.data_api_api import DataAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestDataAPIApi(unittest.TestCase):
    """DataAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.data_api_api.DataAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_publish_data_using_post(self):
        """Test case for publish_data_using_post

        publishData  # noqa: E501
        """
        pass

    def test_query_latest_summary_for_resources_using_post(self):
        """Test case for query_latest_summary_for_resources_using_post

        queryLatestSummaryForResources  # noqa: E501
        """
        pass

    def test_query_latest_values_for_resources_using_post(self):
        """Test case for query_latest_values_for_resources_using_post

        queryLatestValuesForResources  # noqa: E501
        """
        pass

    def test_query_time_range_using_post(self):
        """Test case for query_time_range_using_post

        queryTimeRange  # noqa: E501
        """
        pass

    def test_retrieve_latest_summary_using_get(self):
        """Test case for retrieve_latest_summary_using_get

        retrieveLatestSummary  # noqa: E501
        """
        pass

    def test_retrieve_latest_values_using_get(self):
        """Test case for retrieve_latest_values_using_get

        retrieveLatestValues  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class ParticipatorySensingAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_ps_resource(self, resource_dto, **kwargs):  # noqa: E501
        """Create a Participatory Sensing Resource with an autogenerated uri  # noqa: E501

        Provides means to create a participatory sensing resource and setup its properties in one call, with an autogenerated uri for it  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ps_resource(resource_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AParticipatorySensingResourceRequestAPIModel resource_dto: Resource to be created and used for participatory sensing. (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_ps_resource_with_http_info(resource_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.create_ps_resource_with_http_info(resource_dto, **kwargs)  # noqa: E501
            return data

    def create_ps_resource_with_http_info(self, resource_dto, **kwargs):  # noqa: E501
        """Create a Participatory Sensing Resource with an autogenerated uri  # noqa: E501

        Provides means to create a participatory sensing resource and setup its properties in one call, with an autogenerated uri for it  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ps_resource_with_http_info(resource_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AParticipatorySensingResourceRequestAPIModel resource_dto: Resource to be created and used for participatory sensing. (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_ps_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'resource_dto' is set
        if ('resource_dto' not in params or
                params['resource_dto'] is None):
            raise ValueError("Missing the required parameter `resource_dto` when calling `create_ps_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'resource_dto' in params:
            body_params = params['resource_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/ps/resource', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_ps_resource(self, uuid, **kwargs):  # noqa: E501
        """Delete a Participatory Sensing Resource  # noqa: E501

        Provides means to delete a participatory sensing resource   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ps_resource(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Participatory Sensing Resource UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_ps_resource_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_ps_resource_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def delete_ps_resource_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Delete a Participatory Sensing Resource  # noqa: E501

        Provides means to delete a participatory sensing resource   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ps_resource_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Participatory Sensing Resource UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ps_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `delete_ps_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/ps/resource/{uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def publish_ps_data(self, publish_data_list_dto, **kwargs):  # noqa: E501
        """Publish data to a Participatory Sensing Resource.  # noqa: E501

        Provides means to publish data to a participatory sensing resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.publish_ps_data(publish_data_list_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListOfParticipatorySensingDataAPIModel publish_data_list_dto: List of PublishDataDTO to be published to a participatory sensing resource. (required)
        :return: ListOfParticipatorySensingDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.publish_ps_data_with_http_info(publish_data_list_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.publish_ps_data_with_http_info(publish_data_list_dto, **kwargs)  # noqa: E501
            return data

    def publish_ps_data_with_http_info(self, publish_data_list_dto, **kwargs):  # noqa: E501
        """Publish data to a Participatory Sensing Resource.  # noqa: E501

        Provides means to publish data to a participatory sensing resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.publish_ps_data_with_http_info(publish_data_list_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListOfParticipatorySensingDataAPIModel publish_data_list_dto: List of PublishDataDTO to be published to a participatory sensing resource. (required)
        :return: ListOfParticipatorySensingDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_data_list_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method publish_ps_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_data_list_dto' is set
        if ('publish_data_list_dto' not in params or
                params['publish_data_list_dto'] is None):
            raise ValueError("Missing the required parameter `publish_data_list_dto` when calling `publish_ps_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'publish_data_list_dto' in params:
            body_params = params['publish_data_list_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/ps/data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListOfParticipatorySensingDataAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from sparkworks_client.models.a_participatory_sensing_resource_request_api_model import AParticipatorySensingResourceRequestAPIModel
from sparkworks_client.models.collection_of_data_query_criteria_request_api_model import CollectionOfDataQueryCriteriaRequestAPIModel
from sparkworks_client.models.command_api_model import CommandAPIModel
from sparkworks_client.models.gateway_create_dto import GatewayCreateDTO
from sparkworks_client.models.gateway_dto import GatewayDTO
from sparkworks_client.models.gateway_query_dto import GatewayQueryDTO
from sparkworks_client.models.group_create_dto import GroupCreateDTO
from sparkworks_client.models.group_dto import GroupDTO
from sparkworks_client.models.group_node_dto import GroupNodeDTO
from sparkworks_client.models.group_update_dto import GroupUpdateDTO
from sparkworks_client.models.list_of_participatory_sensing_data_api_model import ListOfParticipatorySensingDataAPIModel
from sparkworks_client.models.list_of_query_criteria_within_a_timeframe_request_api_model import ListOfQueryCriteriaWithinATimeframeRequestAPIModel
from sparkworks_client.models.participatory_sensing_data_api_model import ParticipatorySensingDataAPIModel
from sparkworks_client.models.phenomenon_create_dto import PhenomenonCreateDTO
from sparkworks_client.models.phenomenon_dto import PhenomenonDTO
from sparkworks_client.models.phenomenon_query_dto import PhenomenonQueryDTO
from sparkworks_client.models.phenomenon_update_dto import PhenomenonUpdateDTO
from sparkworks_client.models.registry_pair_dto import RegistryPairDTO
from sparkworks_client.models.registry_record_dto import RegistryRecordDTO
from sparkworks_client.models.resource_analytics_data_response_api_model import ResourceAnalyticsDataResponseAPIModel
from sparkworks_client.models.resource_create_dto import ResourceCreateDTO
from sparkworks_client.models.resource_dto import ResourceDTO
from sparkworks_client.models.resource_latest_data_response_api_model import ResourceLatestDataResponseAPIModel
from sparkworks_client.models.resource_latest_values_response_api_model import ResourceLatestValuesResponseAPIModel
from sparkworks_client.models.resource_query_criteria_request_api_model import ResourceQueryCriteriaRequestAPIModel
from sparkworks_client.models.resource_query_criteria_request_within_a_timeframe_api_model import ResourceQueryCriteriaRequestWithinATimeframeAPIModel
from sparkworks_client.models.resource_query_criteria_within_a_timeframe_response_api_model import ResourceQueryCriteriaWithinATimeframeResponseAPIModel
from sparkworks_client.models.resource_query_dto import ResourceQueryDTO
from sparkworks_client.models.resource_update_dto import ResourceUpdateDTO
from sparkworks_client.models.single_resource_measurement_api_model import SingleResourceMeasurementAPIModel
from sparkworks_client.models.the_resource_summary_data_api_model import TheResourceSummaryDataAPIModel
from sparkworks_client.models.unit_conversion_create_dto import UnitConversionCreateDTO
from sparkworks_client.models.unit_conversion_dto import UnitConversionDTO
from sparkworks_client.models.unit_conversion_query_dto import UnitConversionQueryDTO
from sparkworks_client.models.unit_create_dto import UnitCreateDTO
from sparkworks_client.models.unit_dto import UnitDTO
from sparkworks_client.models.unit_query_dto import UnitQueryDTO
from sparkworks_client.models.unit_update_dto import UnitUpdateDTO
